# Release notes

```{include} /release-notes/release-latest.md
```

## Version 0.9

```{include} /release-notes/0.9.2.md
```

```{include} /release-notes/0.9.1.md
```

```{include} /release-notes/0.9.0.md
```

## Version 0.8

```{include} /release-notes/0.8.1.md
```

```{include} /release-notes/0.8.0.md
```

## Version 0.7

```{include} /release-notes/0.7.8.md
```

```{include} /release-notes/0.7.7.md
```

```{include} /release-notes/0.7.6.md
```

```{include} /release-notes/0.7.5.md
```

```{include} /release-notes/0.7.4.md
```

```{include} /release-notes/0.7.3.md
```

```{include} /release-notes/0.7.2.md
```

```{include} /release-notes/0.7.0.md
```

## Version 0.6

```{include} /release-notes/0.6.0.md
```

## Version 0.5

```{include} /release-notes/0.5.0.md
```

## Version 0.4

```{include} /release-notes/0.4.0.md
```
